@@ -12,7 +12,7 @@ import torch
 import numpy as np
 from onnxconverter_common.topology import Variable
 from onnxconverter_common.registration import register_converter
-from .._base_operator import BaseOperator
+from .._physical_operator import PhysicalOperator
 from .._pipeline_implementations import Concat
 
 
@@ -29,7 +29,7 @@ def convert_sparkml_vector_assembler(operator, device, extra_config):
         A PyTorch model
     """
 
-    return Concat()
+    return Concat(operator)
 
 
 register_converter("SparkMLVectorAssembler", convert_sparkml_vector_assembler)
